=== modified file 'drizzled/calendar.cc'
--- drizzled/calendar.cc	2009-02-27 17:57:02 +0000
+++ drizzled/calendar.cc	2009-02-28 17:49:35 +0000
@@ -479,3 +479,43 @@
 
   return week_number;
 }
+
+/**
+ * Takes a number in the form [YY]YYMM and converts it into
+ * a number of months.
+ *
+ * @param Period in the form [YY]YYMM
+ */
+uint32_t year_month_to_months(uint32_t year_month)
+{
+  if (year_month == 0)
+    return 0L;
+
+  uint32_t years= year_month / 100;
+  if (years < CALENDAR_YY_PART_YEAR)
+    years+= 2000;
+  else if (years < 100)
+    years+= 1900;
+
+  uint32_t months= year_month % 100;
+  return (years * 12) + (months - 1);
+}
+
+/**
+ * Takes a number of months and converts it to
+ * a period in the form YYYYMM.
+ *
+ * @param Number of months
+ */
+uint32_t months_to_year_month(uint32_t months)
+{
+  if (months == 0L)
+    return 0L;
+
+  uint32_t years= (months / 12);
+
+  if (years < 100)
+    years+= (years < CALENDAR_YY_PART_YEAR) ? 2000 : 1900;
+
+  return (years * 100) + (months % 12) + 1;
+}

=== modified file 'drizzled/calendar.h'
--- drizzled/calendar.h	2009-02-04 15:44:25 +0000
+++ drizzled/calendar.h	2009-02-28 17:49:35 +0000
@@ -51,6 +51,8 @@
 #define UNIX_EPOCH_MAX_YEARS 2038
 #define UNIX_EPOCH_MIN_YEARS 1970
 
+#define CALENDAR_YY_PART_YEAR 70
+
 /**
  * The following constants define the system of calculating the number
  * of days in various periods of time in the Gregorian calendar.
@@ -314,6 +316,22 @@
                                            , uint32_t month
                                            , uint32_t day
                                            , uint32_t *year_out);
+/**
+ * Takes a number in the form [YY]YYMM and converts it into
+ * a number of months.
+ *
+ * @param Period in the form [YY]YYMM
+ */
+uint32_t year_month_to_months(uint32_t year_month);
+
+/**
+ * Takes a number of months and converts it to
+ * a period in the form YYYYMM.
+ *
+ * @param Number of months
+ */
+uint32_t months_to_year_month(uint32_t months);
+
 #ifdef __cplusplus
 }
 #endif

=== modified file 'drizzled/function/time/period_add.cc'
--- drizzled/function/time/period_add.cc	2009-02-20 08:45:29 +0000
+++ drizzled/function/time/period_add.cc	2009-02-28 17:49:35 +0000
@@ -17,21 +17,20 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include <drizzled/server_includes.h>
+#include "drizzled/server_includes.h"
 #include CSTDINT_H
-#include <drizzled/function/time/period_add.h>
+#include "drizzled/function/time/period_add.h"
+#include "drizzled/calendar.h"
 
 int64_t Item_func_period_add::val_int()
 {
   assert(fixed == 1);
-  uint32_t period= (uint32_t)args[0]->val_int();
-  int months=(int) args[1]->val_int();
+  uint32_t period= (uint32_t) args[0]->val_int();
+  uint32_t months= (uint32_t) args[1]->val_int();
 
-  if ((null_value=args[0]->null_value || args[1]->null_value) ||
+  if ((null_value= args[0]->null_value || args[1]->null_value) ||
       period == 0L)
     return 0; /* purecov: inspected */
-  return (int64_t)
-    convert_month_to_period((uint) ((int) convert_period_to_month(period)+
-                                    months));
+
+  return (int64_t) months_to_year_month(year_month_to_months(period) + months);
 }
-

=== modified file 'drizzled/function/time/period_diff.cc'
--- drizzled/function/time/period_diff.cc	2009-02-20 08:45:29 +0000
+++ drizzled/function/time/period_diff.cc	2009-02-28 17:49:35 +0000
@@ -17,9 +17,10 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include <drizzled/server_includes.h>
+#include "drizzled/server_includes.h"
 #include CSTDINT_H
-#include <drizzled/function/time/period_diff.h>
+#include "drizzled/function/time/period_diff.h"
+#include "drizzled/calendar.h"
 
 int64_t Item_func_period_diff::val_int()
 {
@@ -29,8 +30,5 @@
 
   if ((null_value=args[0]->null_value || args[1]->null_value))
     return 0; /* purecov: inspected */
-  return (int64_t) ((long) convert_period_to_month(period1)-
-                     (long) convert_period_to_month(period2));
+  return (int64_t) (year_month_to_months(period1) -year_month_to_months(period2));
 }
-
-

=== modified file 'drizzled/time.cc'
--- drizzled/time.cc	2009-02-28 17:49:22 +0000
+++ drizzled/time.cc	2009-02-28 17:49:35 +0000
@@ -185,35 +185,6 @@
   return;
 }
 
-	/* Functions to handle periods */
-
-uint32_t convert_period_to_month(uint32_t period)
-{
-  uint32_t a,b;
-  if (period == 0)
-    return 0L;
-  if ((a=period/100) < YY_PART_YEAR)
-    a+=2000;
-  else if (a < 100)
-    a+=1900;
-  b=period%100;
-  return a*12+b-1;
-}
-
-
-uint32_t convert_month_to_period(uint32_t month)
-{
-  uint32_t year;
-  if (month == 0L)
-    return 0L;
-  if ((year=month/12) < 100)
-  {
-    year+=(year < YY_PART_YEAR) ? 2000 : 1900;
-  }
-  return year*100+month%12+1;
-}
-
-
 /*
   Convert a timestamp string to a DRIZZLE_TIME value and produce a warning
   if string was truncated during conversion.

